@@ -18,5 +18,8 @@ else:
 
 try:
     from comparable.base import SimpleComparable, CompoundComparable
+    from comparable import simple
+    from comparable import compound
+    from comparable import tools
 except ImportError:  # pragma: no cover, manual test
     pass
