@@ -30,7 +30,7 @@ class _Base(object):  # pylint: disable=R0903
         return "{}({}{})".format(name, args_repr, kwargs_repr)
 
 
-class Similarity(_Base):
+class Similarity(_Base):  # pylint: disable=R0903
     """Represents the similarity between two objects."""
 
     def __init__(self, value, threshold=1.0):
@@ -153,7 +153,7 @@ class Comparable(_Base, metaclass=ABCMeta):
     should be considered.
 
     Both types of subclasses may also override the 'threshold'
-    property to change the default similarity threshold.
+    attribute to change the default similarity threshold.
     """
 
     def __eq__(self, other):
@@ -175,11 +175,7 @@ class Comparable(_Base, metaclass=ABCMeta):
         """
         return {}
 
-    @property
-    def threshold(self):  # pragma: no cover, abstract
-        """Get the ratio for two objects to be considered "similar".
-        """
-        return 1.0
+    threshold = 1.0  # ratio for two objects to be considered "similar"
 
     @abstractmethod
     def equality(self, other):
@@ -198,9 +194,9 @@ class Comparable(_Base, metaclass=ABCMeta):
                 logging.debug("{}.{}: {}".format(cname, aname, error))
                 return False
             self.log(attr1, attr2, '==', cname=cname, aname=aname)
-            eq = (attr1 == attr2)
-            self.log(attr1, attr2, '==', cname=cname, aname=aname, result=eq)
-            if not eq:
+            eql = (attr1 == attr2)
+            self.log(attr1, attr2, '==', cname=cname, aname=aname, result=eql)
+            if not eql:
                 return False
 
         return True
@@ -261,7 +257,7 @@ class Comparable(_Base, metaclass=ABCMeta):
         return Similarity(value, threshold=threshold)
 
     @staticmethod
-    def log(obj1, obj2, op, cname=None, aname=None, result=None):
+    def log(obj1, obj2, sym, cname=None, aname=None, result=None):  # pylint: disable=R0913
         """Log the objects being compared and the result.
 
         When no result object is specified, subsequence calls will have an
@@ -270,12 +266,12 @@ class Comparable(_Base, metaclass=ABCMeta):
 
         @param obj1: first object
         @param obj2: second object
-        @param op: operation being performed ('==' or '%')
+        @param sym: operation being performed ('==' or '%')
         @param cname: name of class (when attributes are being compared)
         @param aname: name of attribute (when attributes are being compared)
         @param result: outcome of comparison
         """
-        fmt = "{o1} {op} {o2} : {r}"
+        fmt = "{o1} {sym} {o2} : {r}"
         if cname or aname:
             assert cname and aname  # both must be specified
             fmt = "{c}.{a}: " + fmt
@@ -289,7 +285,7 @@ class Comparable(_Base, metaclass=ABCMeta):
             fmt = _Indent.indent(fmt)
 
         logging.info(fmt.format(o1=repr(obj1), o2=repr(obj2),
-                                c=cname, a=aname, op=op, r=result))
+                                c=cname, a=aname, sym=sym, r=result))
 
 
 class SimpleComparable(Comparable):  # pylint: disable=W0223
@@ -297,7 +293,7 @@ class SimpleComparable(Comparable):  # pylint: disable=W0223
 
     Subclasses directly comparable must override the 'equality' and
     'similarity' methods to return a bool and 'Similarity' object,
-    respectively. They may also override the 'threshold' property
+    respectively. They may also override the 'threshold' attribute
     to change the default similarity threshold.
     """
 
@@ -314,7 +310,7 @@ class CompoundComparable(Comparable):  # pylint: disable=W0223
     Subclasses comparable by attributes must override the
     'attributes' property to define which (Comparable) attributes
     should be considered. They may also override the 'threshold'
-    property to change the default similarity threshold.
+    attribute to change the default similarity threshold.
     """
 
     def equality(self, other):
